// Sample data (replace this with your actual data)
const temperatureData = {
  2020: {
    labels: [
      'Jan',
      'Feb',
      'Mar',
      'Apr',
      'May',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Oct',
      'Nov',
      'Dec',
    ],
    datasets: [
      // Temperature dataset
      {
        label: 'Temperature 2020',
        backgroundColor: 'rgba(255, 99, 132, 0.2)',
        borderColor: 'rgba(255, 99, 132, 1)',
        borderWidth: 1,
        data: [
          30,
          32,
          34,
          35,
          36,
          37,
          37,
          37,
          36,
          34,
          32,
          30, // Temperature data for 2020 in Celsius
        ],
      },
    ],
  },
  2021: {
    labels: [
      'Jan',
      'Feb',
      'Mar',
      'Apr',
      'May',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Oct',
      'Nov',
      'Dec',
    ],
    datasets: [
      // Temperature dataset
      {
        label: 'Temperature 2021',
        backgroundColor: 'rgba(255, 99, 132, 0.2)',
        borderColor: 'rgba(255, 99, 132, 1)',
        borderWidth: 1,
        data: [
          29,
          31,
          33,
          35,
          36,
          37,
          38,
          38,
          36,
          34,
          31,
          29, // Temperature data for 2021 in Celsius
        ],
      },
    ],
  },
  2022: {
    labels: [
      'Jan',
      'Feb',
      'Mar',
      'Apr',
      'May',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Oct',
      'Nov',
      'Dec',
    ],
    datasets: [
      // Temperature dataset
      {
        label: 'Temperature 2022',
        backgroundColor: 'rgba(255, 99, 132, 0.2)',
        borderColor: 'rgba(255, 99, 132, 1)',
        borderWidth: 1,
        data: [
          28,
          30,
          32,
          34,
          36,
          37,
          38,
          37,
          35,
          32,
          30,
          28, // Temperature data for 2022 in Celsius
        ],
      },
    ],
  },
};

const pressureData = {
  2020: {
    labels: [
      'Jan',
      'Feb',
      'Mar',
      'Apr',
      'May',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Oct',
      'Nov',
      'Dec',
    ],
    datasets: [
      // Pressure dataset
      {
        label: 'Pressure 2020',
        backgroundColor: 'rgba(54, 162, 235, 0.2)',
        borderColor: 'rgba(54, 162, 235, 1)',
        borderWidth: 1,
        data: [
          1010,
          1012,
          1010,
          1008,
          1009,
          1010,
          1011,
          1010,
          1009,
          1010,
          1012,
          1011, // Pressure data for 2020 in hPa
        ],
      },
    ],
  },
  2021: {
    labels: [
      'Jan',
      'Feb',
      'Mar',
      'Apr',
      'May',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Oct',
      'Nov',
      'Dec',
    ],
    datasets: [
      // Pressure dataset
      {
        label: 'Pressure 2021',
        backgroundColor: 'rgba(54, 162, 235, 0.2)',
        borderColor: 'rgba(54, 162, 235, 1)',
        borderWidth: 1,
        data: [
          1011,
          1013,
          1011,
          1009,
          1010,
          1011,
          1012,
          1011,
          1010,
          1011,
          1013,
          1012, // Pressure data for 2021 in hPa
        ],
      },
    ],
  },
  2022: {
    labels: [
      'Jan',
      'Feb',
      'Mar',
      'Apr',
      'May',
      'Jun',
      'Jul',
      'Aug',
      'Sep',
      'Oct',
      'Nov',
      'Dec',
    ],
    datasets: [
      // Pressure dataset
      {
        label: 'Pressure 2022',
        backgroundColor: 'rgba(54, 162, 235, 0.2)',
        borderColor: 'rgba(54, 162, 235, 1)',
        borderWidth: 1,
        data: [
          1010,
          1012,
          1010,
          1009,
          1009,
          1010,
          1011,
          1010,
          1009,
          1010,
          1012,
          1011, // Pressure data for 2022 in hPa
        ],
      },
    ],
  },
};

// Configuration options for temperature chart
const temperatureConfig = {
  type: 'line',
  data: temperatureData['2020'], // Initial data for 2020
  options: {
    plugins: {
      title: {
        display: true,
        text: 'Temperature Variation over Months in 2020',
      },
      tooltip: {
        enabled: true,
        intersect: false,
      },
      legend: {
        display: true,
        position: 'bottom',
      },
    },
    scales: {
      x: {
        title: {
          display: true,
          text: 'Month',
        },
      },
      y: {
        type: 'linear',
        display: true,
        position: 'left',
        title: {
          display: true,
          text: 'Temperature (°C)',
        },
      },
    },
    elements: {
      line: {
        fill: true,
      },
    },
  },
};

// Configuration options for pressure chart
const pressureConfig = {
  type: 'line',
  data: pressureData['2020'], // Initial data for 2020
  options: {
    plugins: {
      title: {
        display: true,
        text: 'Pressure Variation over Months in 2020',
      },
      tooltip: {
        enabled: true,
        intersect: false,
      },
      legend: {
        display: true,
        position: 'bottom',
      },
    },
    scales: {
      x: {
        title: {
          display: true,
          text: 'Month',
        },
      },
      y: {
        type: 'linear',
        display: true,
        position: 'left',
        title: {
          display: true,
          text: 'Pressure (hPa)',
        },
      },
    },
    elements: {
      line: {
        fill: true,
      },
    },
  },
};

// Create temperature chart
var temperatureChart = new Chart(
  'temperatureChart',
  temperatureConfig,
);

// Create pressure chart
var pressureChart = new Chart(
  'pressureChart',
  pressureConfig,
);

// Function to update the chart based on selected year
function updateChart(year) {
  temperatureChart.data = temperatureData[year];
  pressureChart.data = pressureData[year];
  temperatureChart.options.plugins.title.text = `Temperature Variation over Months in ${year}`;
  pressureChart.options.plugins.title.text = `Pressure Variation over Months in ${year}`;
  temperatureChart.update();
  pressureChart.update();
}

// Link the two charts
temperatureChart.options.onHover = function (
  event,
  chartElement,
) {
  if (chartElement && chartElement.length > 0) {
    var index = chartElement[0].index;
    pressureChart.setActiveElements([
      { datasetIndex: 0, index },
    ]);
  } else {
    pressureChart.setActiveElements([]);
  }
};

pressureChart.options.onHover = function (
  event,
  chartElement,
) {
  if (chartElement && chartElement.length > 0) {
    var index = chartElement[0].index;
    temperatureChart.setActiveElements([
      { datasetIndex: 0, index },
    ]);
  } else {
    temperatureChart.setActiveElements([]);
  }
};